@@ -51,10 +51,10 @@ def _request_to_tbs_certificate(
             for _, extension in enumerate(extensions):
                 if ignore_auth_exts is not None and ignore_auth_exts is True:
                     if (
-                        extension["extn_id"] == "2.5.29.35"
-                        or extension["extn_id"] == "2.5.29.14"
-                        or extension["extn_id"] == "1.3.6.1.5.5.7.1.1"
-                        or extension["extn_id"] == "2.5.29.31"
+                        extension["extn_id"].dotted == "2.5.29.35"
+                        or extension["extn_id"].dotted == "2.5.29.14"
+                        or extension["extn_id"].dotted == "1.3.6.1.5.5.7.1.1"
+                        or extension["extn_id"].dotted == "2.5.29.31"
                     ):
                         continue
 
